@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2005 IBM Corporation and others.
+ * Copyright (c) 2000, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -48,10 +48,8 @@ import org.eclipse.jdt.core.JavaModelException;
 
 import org.eclipse.jdt.ui.StandardJavaElementContentProvider;
 
-import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-
 class JavaBrowsingContentProvider extends StandardJavaElementContentProvider implements IElementChangedListener {
 
 	private StructuredViewer fViewer;
@@ -269,7 +267,7 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 
 			if (fBrowsingPart.isAncestorOf(element, fInput)) {
 				if (element instanceof IWorkingCopy && ((IWorkingCopy)element).isWorkingCopy()) {
-					postAdjustInputAndSetSelection(JavaModelUtil.toOriginal((IJavaElement) fInput));
+					postAdjustInputAndSetSelection(((IJavaElement) fInput).getPrimaryElement());
 				} else
 					postAdjustInputAndSetSelection(null);
 			}
